import * as WorkerThreads from "../worker_threads";
function assertMessagePort(port) {
    if (!port) {
        throw Error("Invariant violation: MessagePort to parent is not available.");
    }
    return port;
}
const isWorkerRuntime = function isWorkerRuntime() {
    return !WorkerThreads.isMainThread;
};
const postMessageToMaster = function postMessageToMaster(data, transferList) {
    assertMessagePort(WorkerThreads.parentPort).postMessage(data, transferList);
};
const subscribeToMasterMessages = function subscribeToMasterMessages(onMessage) {
    if (!WorkerThreads.parentPort) {
        throw Error("Invariant violation: MessagePort to parent is not available.");
    }
    const messageHandler = (message) => {
        onMessage(message);
    };
    const unsubscribe = () => {
        assertMessagePort(WorkerThreads.parentPort).off("message", messageHandler);
    };
    assertMessagePort(WorkerThreads.parentPort).on("message", messageHandler);
    return unsubscribe;
};
export default {
    isWorkerRuntime,
    postMessageToMaster,
    subscribeToMasterMessages
};
